==> quarkus-infinispan-client-2.0.1.Final-sources.jar: io/quarkus/infinispan/client/runtime/InfinispanClientRuntimeConfig$$accessor.java <==
package io.quarkus.infinispan.client.runtime;
public final class InfinispanClientRuntimeConfig$$accessor {
    private InfinispanClientRuntimeConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_clientIntelligence(Object __instance) {
        return ((InfinispanClientRuntimeConfig)__instance).clientIntelligence;
    }
    @SuppressWarnings("unchecked")
    public static void set_clientIntelligence(Object __instance, Object clientIntelligence) {
        ((InfinispanClientRuntimeConfig)__instance).clientIntelligence = (java.util.Optional<String>)clientIntelligence;
    }
    @SuppressWarnings("unchecked")
    public static Object get_useAuth(Object __instance) {
        return ((InfinispanClientRuntimeConfig)__instance).useAuth;
    }
    @SuppressWarnings("unchecked")
    public static void set_useAuth(Object __instance, Object useAuth) {
        ((InfinispanClientRuntimeConfig)__instance).useAuth = (java.util.Optional<String>)useAuth;
    }
    @SuppressWarnings("unchecked")
    public static Object get_authUsername(Object __instance) {
        return ((InfinispanClientRuntimeConfig)__instance).authUsername;
    }
    @SuppressWarnings("unchecked")
    public static void set_authUsername(Object __instance, Object authUsername) {
        ((InfinispanClientRuntimeConfig)__instance).authUsername = (java.util.Optional<String>)authUsername;
    }
    @SuppressWarnings("unchecked")
    public static Object get_authPassword(Object __instance) {
        return ((InfinispanClientRuntimeConfig)__instance).authPassword;
    }
    @SuppressWarnings("unchecked")
    public static void set_authPassword(Object __instance, Object authPassword) {
        ((InfinispanClientRuntimeConfig)__instance).authPassword = (java.util.Optional<String>)authPassword;
    }
    @SuppressWarnings("unchecked")
    public static Object get_authRealm(Object __instance) {
        return ((InfinispanClientRuntimeConfig)__instance).authRealm;
    }
    @SuppressWarnings("unchecked")
    public static void set_authRealm(Object __instance, Object authRealm) {
        ((InfinispanClientRuntimeConfig)__instance).authRealm = (java.util.Optional<String>)authRealm;
    }
    @SuppressWarnings("unchecked")
    public static Object get_authServerName(Object __instance) {
        return ((InfinispanClientRuntimeConfig)__instance).authServerName;
    }
    @SuppressWarnings("unchecked")
    public static void set_authServerName(Object __instance, Object authServerName) {
        ((InfinispanClientRuntimeConfig)__instance).authServerName = (java.util.Optional<String>)authServerName;
    }
    @SuppressWarnings("unchecked")
    public static Object get_authClientSubject(Object __instance) {
        return ((InfinispanClientRuntimeConfig)__instance).authClientSubject;
    }
    @SuppressWarnings("unchecked")
    public static void set_authClientSubject(Object __instance, Object authClientSubject) {
        ((InfinispanClientRuntimeConfig)__instance).authClientSubject = (java.util.Optional<String>)authClientSubject;
    }
    @SuppressWarnings("unchecked")
    public static Object get_authCallbackHandler(Object __instance) {
        return ((InfinispanClientRuntimeConfig)__instance).authCallbackHandler;
    }
    @SuppressWarnings("unchecked")
    public static void set_authCallbackHandler(Object __instance, Object authCallbackHandler) {
        ((InfinispanClientRuntimeConfig)__instance).authCallbackHandler = (java.util.Optional<String>)authCallbackHandler;
    }
    @SuppressWarnings("unchecked")
    public static Object get_saslMechanism(Object __instance) {
        return ((InfinispanClientRuntimeConfig)__instance).saslMechanism;
    }
    @SuppressWarnings("unchecked")
    public static void set_saslMechanism(Object __instance, Object saslMechanism) {
        ((InfinispanClientRuntimeConfig)__instance).saslMechanism = (java.util.Optional<String>)saslMechanism;
    }
    @SuppressWarnings("unchecked")
    public static Object get_trustStore(Object __instance) {
        return ((InfinispanClientRuntimeConfig)__instance).trustStore;
    }
    @SuppressWarnings("unchecked")
    public static void set_trustStore(Object __instance, Object trustStore) {
        ((InfinispanClientRuntimeConfig)__instance).trustStore = (java.util.Optional<String>)trustStore;
    }
    @SuppressWarnings("unchecked")
    public static Object get_trustStorePassword(Object __instance) {
        return ((InfinispanClientRuntimeConfig)__instance).trustStorePassword;
    }
    @SuppressWarnings("unchecked")
    public static void set_trustStorePassword(Object __instance, Object trustStorePassword) {
        ((InfinispanClientRuntimeConfig)__instance).trustStorePassword = (java.util.Optional<String>)trustStorePassword;
    }
    @SuppressWarnings("unchecked")
    public static Object get_trustStoreType(Object __instance) {
        return ((InfinispanClientRuntimeConfig)__instance).trustStoreType;
    }
    @SuppressWarnings("unchecked")
    public static void set_trustStoreType(Object __instance, Object trustStoreType) {
        ((InfinispanClientRuntimeConfig)__instance).trustStoreType = (java.util.Optional<String>)trustStoreType;
    }
}

==> quarkus-infinispan-client-2.2.2.Final-sources.jar: io/quarkus/infinispan/client/runtime/InfinispanClientRuntimeConfig$$accessor.java <==
package io.quarkus.infinispan.client.runtime;
public final class InfinispanClientRuntimeConfig$$accessor {
    private InfinispanClientRuntimeConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_useSchemaRegistration(Object __instance) {
        return ((InfinispanClientRuntimeConfig)__instance).useSchemaRegistration;
    }
    @SuppressWarnings("unchecked")
    public static void set_useSchemaRegistration(Object __instance, Object useSchemaRegistration) {
        ((InfinispanClientRuntimeConfig)__instance).useSchemaRegistration = (java.util.Optional<Boolean>)useSchemaRegistration;
    }
    @SuppressWarnings("unchecked")
    public static Object get_clientIntelligence(Object __instance) {
        return ((InfinispanClientRuntimeConfig)__instance).clientIntelligence;
    }
    @SuppressWarnings("unchecked")
    public static void set_clientIntelligence(Object __instance, Object clientIntelligence) {
        ((InfinispanClientRuntimeConfig)__instance).clientIntelligence = (java.util.Optional<String>)clientIntelligence;
    }
    @SuppressWarnings("unchecked")
    public static Object get_useAuth(Object __instance) {
        return ((InfinispanClientRuntimeConfig)__instance).useAuth;
    }
    @SuppressWarnings("unchecked")
    public static void set_useAuth(Object __instance, Object useAuth) {
        ((InfinispanClientRuntimeConfig)__instance).useAuth = (java.util.Optional<Boolean>)useAuth;
    }
    @SuppressWarnings("unchecked")
    public static Object get_authUsername(Object __instance) {
        return ((InfinispanClientRuntimeConfig)__instance).authUsername;
    }
    @SuppressWarnings("unchecked")
    public static void set_authUsername(Object __instance, Object authUsername) {
        ((InfinispanClientRuntimeConfig)__instance).authUsername = (java.util.Optional<String>)authUsername;
    }
    @SuppressWarnings("unchecked")
    public static Object get_authPassword(Object __instance) {
        return ((InfinispanClientRuntimeConfig)__instance).authPassword;
    }
    @SuppressWarnings("unchecked")
    public static void set_authPassword(Object __instance, Object authPassword) {
        ((InfinispanClientRuntimeConfig)__instance).authPassword = (java.util.Optional<String>)authPassword;
    }
    @SuppressWarnings("unchecked")
    public static Object get_authRealm(Object __instance) {
        return ((InfinispanClientRuntimeConfig)__instance).authRealm;
    }
    @SuppressWarnings("unchecked")
    public static void set_authRealm(Object __instance, Object authRealm) {
        ((InfinispanClientRuntimeConfig)__instance).authRealm = (java.util.Optional<String>)authRealm;
    }
    @SuppressWarnings("unchecked")
    public static Object get_authServerName(Object __instance) {
        return ((InfinispanClientRuntimeConfig)__instance).authServerName;
    }
    @SuppressWarnings("unchecked")
    public static void set_authServerName(Object __instance, Object authServerName) {
        ((InfinispanClientRuntimeConfig)__instance).authServerName = (java.util.Optional<String>)authServerName;
    }
    @SuppressWarnings("unchecked")
    public static Object get_authClientSubject(Object __instance) {
        return ((InfinispanClientRuntimeConfig)__instance).authClientSubject;
    }
    @SuppressWarnings("unchecked")
    public static void set_authClientSubject(Object __instance, Object authClientSubject) {
        ((InfinispanClientRuntimeConfig)__instance).authClientSubject = (java.util.Optional<String>)authClientSubject;
    }
    @SuppressWarnings("unchecked")
    public static Object get_authCallbackHandler(Object __instance) {
        return ((InfinispanClientRuntimeConfig)__instance).authCallbackHandler;
    }
    @SuppressWarnings("unchecked")
    public static void set_authCallbackHandler(Object __instance, Object authCallbackHandler) {
        ((InfinispanClientRuntimeConfig)__instance).authCallbackHandler = (java.util.Optional<String>)authCallbackHandler;
    }
    @SuppressWarnings("unchecked")
    public static Object get_saslMechanism(Object __instance) {
        return ((InfinispanClientRuntimeConfig)__instance).saslMechanism;
    }
    @SuppressWarnings("unchecked")
    public static void set_saslMechanism(Object __instance, Object saslMechanism) {
        ((InfinispanClientRuntimeConfig)__instance).saslMechanism = (java.util.Optional<String>)saslMechanism;
    }
    @SuppressWarnings("unchecked")
    public static Object get_trustStore(Object __instance) {
        return ((InfinispanClientRuntimeConfig)__instance).trustStore;
    }
    @SuppressWarnings("unchecked")
    public static void set_trustStore(Object __instance, Object trustStore) {
        ((InfinispanClientRuntimeConfig)__instance).trustStore = (java.util.Optional<String>)trustStore;
    }
    @SuppressWarnings("unchecked")
    public static Object get_trustStorePassword(Object __instance) {
        return ((InfinispanClientRuntimeConfig)__instance).trustStorePassword;
    }
    @SuppressWarnings("unchecked")
    public static void set_trustStorePassword(Object __instance, Object trustStorePassword) {
        ((InfinispanClientRuntimeConfig)__instance).trustStorePassword = (java.util.Optional<String>)trustStorePassword;
    }
    @SuppressWarnings("unchecked")
    public static Object get_trustStoreType(Object __instance) {
        return ((InfinispanClientRuntimeConfig)__instance).trustStoreType;
    }
    @SuppressWarnings("unchecked")
    public static void set_trustStoreType(Object __instance, Object trustStoreType) {
        ((InfinispanClientRuntimeConfig)__instance).trustStoreType = (java.util.Optional<String>)trustStoreType;
    }
}
